@@ -21,6 +21,8 @@ extern struct kbd_ops_struct *kbd_ops;
 #include <asm/arch/keyboard_discovery.h>
 #elif defined(CONFIG_ARCH_PXA_POODLE)
 #include <asm/arch/keyboard_poodle.h>
+#elif defined(CONFIG_ARCH_PXA_SPITZ)
+#include <asm/arch/keyboard_spitz.h>
 #elif defined(CONFIG_ARCH_PXA_CORGI)
 #include <asm/arch/keyboard_corgi.h>
 #elif defined(CONFIG_ARCH_PXA_TOSA)
