@@ -1,3 +1,5 @@
+/* $USAGI: sysctl.h,v 1.23.2.2.2.1 2003/02/05 07:45:49 yoshfuji Exp $ */
+
 /*
  * sysctl.h: General linux system control interface
  *
@@ -129,6 +131,7 @@ enum
 	KERN_CORE_USES_PID=52,		/* int: use core or core.%pid */
 	KERN_TAINTED=53,	/* int: various kernel tainted flags */
 	KERN_CADPID=54,		/* int: PID of the process to notify on CAD */
+	KERN_LOWLATENCY=55,     /* int: enable low latency scheduling */
 };
 
 
@@ -145,15 +148,14 @@ enum
 	VM_PAGERDAEMON=8,	/* struct: Control kswapd behaviour */
 	VM_PGT_CACHE=9,		/* struct: Set page table cache parameters */
 	VM_PAGE_CLUSTER=10,	/* int: set number of pages to swap together */
-       VM_MIN_READAHEAD=12,    /* Min file readahead */
-       VM_MAX_READAHEAD=13     /* Max file readahead */
+	VM_MAX_MAP_COUNT=11,	/* int: Maximum number of active map areas */
+	VM_MIN_READAHEAD=12,    /* Min file readahead */
+	VM_MAX_READAHEAD=13,    /* Max file readahead */
 #ifdef CONFIG_FREEPG_SIGNAL
-	,
-	VM_FREEPG_SIGNAL_PROC=14
+	VM_FREEPG_SIGNAL_PROC=14,
 #endif
 #ifdef CONFIG_ARCH_SHARP_SL
-	,
-	VM_WITHOUT_SWAP=15	/* switch to enable vm for no swap */
+	VM_WITHOUT_SWAP=15,     /* switch to enable vm for no swap */
 #endif
 };
 
@@ -177,7 +179,8 @@ enum
 	NET_TR=14,
 	NET_DECNET=15,
 	NET_ECONET=16,
-	NET_KHTTPD=17
+	NET_KHTTPD=17,
+	NET_IPSEC=18
 };
 
 /* /proc/sys/kernel/random */
@@ -217,7 +220,8 @@ enum
 	NET_CORE_NO_CONG_THRESH=13,
 	NET_CORE_NO_CONG=14,
 	NET_CORE_LO_CONG=15,
-	NET_CORE_MOD_CONG=16
+	NET_CORE_MOD_CONG=16,
+	NET_CORE_DEV_WEIGHT=17
 };
 
 /* /proc/sys/net/ethernet */
@@ -302,7 +306,8 @@ enum
 	NET_TCP_ADV_WIN_SCALE=87,
 	NET_IPV4_NONLOCAL_BIND=88,
 	NET_IPV4_ICMP_RATELIMIT=89,
-	NET_IPV4_ICMP_RATEMASK=90
+	NET_IPV4_ICMP_RATEMASK=90,
+	NET_TCP_TW_REUSE=91
 };
 
 enum {
@@ -347,7 +352,8 @@ enum
 	NET_IPV4_CONF_BOOTP_RELAY=10,
 	NET_IPV4_CONF_LOG_MARTIANS=11,
 	NET_IPV4_CONF_TAG=12,
-	NET_IPV4_CONF_ARPFILTER=13
+	NET_IPV4_CONF_ARPFILTER=13,
+	NET_IPV4_CONF_MEDIUM_ID=14,
 };
 
 /* /proc/sys/net/ipv6 */
@@ -379,7 +385,26 @@ enum {
 	NET_IPV6_DAD_TRANSMITS=7,
 	NET_IPV6_RTR_SOLICITS=8,
 	NET_IPV6_RTR_SOLICIT_INTERVAL=9,
-	NET_IPV6_RTR_SOLICIT_DELAY=10
+	NET_IPV6_RTR_SOLICIT_DELAY=10,
+#ifdef __KERNEL__
+	NET_IPV6_BINDV6ONLY,
+	NET_IPV6_BINDV6ONLY_RESTRICTION,
+	NET_IPV6_ACCEPT_NI,
+	NET_IPV6_USE_TEMPADDR,
+	NET_IPV6_TEMP_VALID_LFT,
+	NET_IPV6_TEMP_PREFERED_LFT,
+	NET_IPV6_REGEN_MAX_RETRY,
+	NET_IPV6_MAX_DESYNC_FACTOR,
+#endif
+};
+
+/* /proc/net/ipsec */
+enum {
+	NET_IPSEC_REPLAY_WINDOW=1,
+	NET_IPSEC_DEBUG_IPV6=5,
+	NET_IPSEC_DEBUG_PFKEY=6,
+	NET_IPSEC_DEBUG_SADB=7,
+	NET_IPSEC_DEBUG_SPD=8,
 };
 
 /* /proc/sys/net/<protocol>/neigh/<dev> */
